跳到主要内容

Error

搜索

枚举 Error 

源代码
pub enum Error {
    FeatureLevelNotSatisfied,
    WindowsError(Error),
}
展开描述

在创建或使用 Direct3D 设备和纹理时可能发生的错误。

变体



FeatureLevelNotSatisfied

所创建的设备至少不支持 11.0 功能等级。



WindowsError(Error)

Windows Runtime 或 Win32 API 调用失败。

包装了 windows::core::Error

trait 实现

源代码

impl Clone for Error

源代码

fn clone(&self) -> Error

返回该值的一个副本。 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 阅读更多
源代码

impl Debug for Error

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Display for Error

源代码

fn fmt(&self, __formatter: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Error for Error

源代码

fn source(&self) -> Option<&(dyn Error + 'static)>

Returns the lower-level source of this error, if any. 阅读更多
1.0.0 · 源代码

fn description(&self) -> &str

👎Deprecated since 1.42.0: use the Display impl or to_string()
1.0.0 · 源代码

fn cause(&self) -> Option<&dyn Error>

👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
源代码

fn provide<'a>(&'a self, request: &mut Request<'a>)

🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type-based access to context intended for error reports. 阅读更多
源代码

impl From<Error> for Error

源代码

fn from(source: Error) -> Self

从输入类型转换为该类型。
源代码

impl From<Error> for Error

源代码

fn from(source: Error) -> Self

从输入类型转换为该类型。
源代码

impl From<Error> for Error

源代码

fn from(source: Error) -> Self

从输入类型转换为该类型。
源代码

impl<E> From<Error> for GraphicsCaptureApiError<E>

源代码

fn from(source: Error) -> Self

从输入类型转换为该类型。
源代码

impl PartialEq for Error

源代码

fn eq(&self, other: &Error) -> bool

测试 selfother 的值是否相等,被 == 使用。
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。 The default implementation is almost always sufficient, and should not be overridden without very good reason.
源代码

impl Eq for Error

源代码

impl StructuralPartialEq for Error

自动 trait 实现



impl Freeze for Error



impl RefUnwindSafe for Error



impl Send for Error



impl Sync for Error



impl Unpin for Error



impl UnsafeUnpin for Error



impl UnwindSafe for Error

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

That is, this conversion is whatever the implementation of From<T> for U chooses to do.

源代码

impl<T> IntoEither for T

源代码

fn into_either(self, into_left: bool) -> Either<Self, Self>

into_lefttrue,则将 self 转换为 Either<Self, Self>Left 变体; 否则将 self 转换为 Either<Self, Self>Right 变体。 阅读更多
源代码

fn into_either_with<F>(self, into_left: F) -> Either<Self, Self>
where F: FnOnce(&Self) -> bool,

into_left(&self) 返回 true,则将 self 转换为 Either<Self, Self>Left 变体; 否则将 self 转换为 Either<Self, Self>Right 变体。 阅读更多
源代码

impl<T> Pointable for T

源代码

const ALIGN: usize

指针的对齐方式。
源代码

type Init = T

初始化器的类型。
源代码

unsafe fn init(init: <T as Pointable>::Init) -> usize

使用给定的初始化器初始化内存。 阅读更多
源代码

unsafe fn deref<'a>(ptr: usize) -> &'a T

解引用给定的指针。 阅读更多
源代码

unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T

可变地解引用给定的指针。 阅读更多
源代码

unsafe fn drop(ptr: usize)

释放给定指针指向的对象。 阅读更多
源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

从借用数据创建自有数据,通常通过克隆实现。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

使用借用数据替换自有数据,通常通过克隆实现。 阅读更多
源代码

impl<T> ToString for T
where T: Display + ?Sized,

源代码

fn to_string(&self) -> String

将给定的值转换为 String阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

在转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

在转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。